"""Collection of functions for the manipulation of time series."""

import os.path as _osp
import sys as _sys

from . import *

__all__ = [
    "autocorrelation",
    "bar",
    "bar_stacked",
    "barh",
    "barh_stacked",
    "bootstrap",
    "boxplot",
    "double_mass",
    "handh",
    "heatmap",
    "hexbin",
    "histogram",
    "kde",
    "kde_time",
    "lag_plot",
    "lognorm_xaxis",
    "lognorm_yaxis",
    "norm_xaxis",
    "norm_yaxis",
    "probability_density",
    "scatter_matrix",
    "target",
    "taylor",
    "time",
    "waterfall",
    "weibull_xaxis",
    "weibull_yaxis",
    "xy",
]


def _main():
    """Set debug and run cltoolbox.main function."""
    if not _osp.exists("debug_plottoolbox"):
        _sys.tracebacklimit = 0

    import cltoolbox
    import numpy as np
    from cltoolbox.rst_text_formatter import (  # W: E402 module level import not at top of file
        RSTHelpFormatter,
    )

    from plottoolbox.toolbox_utils.src.toolbox_utils import tsutils

    @cltoolbox.command("autocorrelation", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(autocorrelation)
    def autocorrelation_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        xlim=None,
        ylim=None,
        grid=False,
        xlabel_rotation=0,
        ylabel_rotation=0,
        por=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
    ):
        """docstring replaced by tsutils.copy_doc"""
        autocorrelation(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            xlabel_rotation=xlabel_rotation,
            ylabel_rotation=ylabel_rotation,
            por=por,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
        )

    @cltoolbox.command("bar", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(bar)
    def bar_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        bar_hatchstyles="auto",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        label_rotation=None,
        label_skip=1,
        force_freq=None,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        bar(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            bar_hatchstyles=bar_hatchstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            label_rotation=label_rotation,
            label_skip=label_skip,
            force_freq=force_freq,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("bar_stacked", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(bar_stacked)
    def bar_stacked_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        bar_hatchstyles="auto",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        label_rotation=None,
        label_skip=1,
        force_freq=None,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        bar_stacked(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            bar_hatchstyles=bar_hatchstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            label_rotation=label_rotation,
            label_skip=label_skip,
            force_freq=force_freq,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("barh", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(barh)
    def barh_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        bar_hatchstyles="auto",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        label_rotation=None,
        label_skip=1,
        force_freq=None,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        barh(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            bar_hatchstyles=bar_hatchstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            label_rotation=label_rotation,
            label_skip=label_skip,
            force_freq=force_freq,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("barh_stacked", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(barh_stacked)
    def barh_stacked_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        bar_hatchstyles="auto",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        label_rotation=None,
        label_skip=1,
        force_freq=None,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        barh_stacked(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            bar_hatchstyles=bar_hatchstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            label_rotation=label_rotation,
            label_skip=label_skip,
            force_freq=force_freq,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("bootstrap", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(bootstrap)
    def bootstrap_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        bootstrap_size=50,
        bootstrap_samples=500,
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        bootstrap(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            bootstrap_size=bootstrap_size,
            bootstrap_samples=bootstrap_samples,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("boxplot", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(boxplot)
    def boxplot_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        boxplot(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("double_mass", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(double_mass)
    def double_mass_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        double_mass(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("handh", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(handh)
    def handh_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        subplots=False,
        sharex=True,
        sharey=False,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        secondary_y=False,
        mark_right=True,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        handh(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            subplots=subplots,
            sharex=sharex,
            sharey=sharey,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            secondary_y=secondary_y,
            mark_right=mark_right,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("heatmap", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(heatmap)
    def heatmap_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        heatmap(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("hexbin", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(hexbin)
    def hexbin_cli(
        input_ts="-",
        reduce_C_function=np.mean,
        gridsize=100,
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        source_units=None,
        target_units=None,
        plot_styles="bright",
    ):
        """docstring replaced by tsutils.copy_doc"""
        hexbin(
            input_ts=input_ts,
            reduce_C_function=reduce_C_function,
            gridsize=gridsize,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
        )

    @cltoolbox.command("histogram", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(histogram)
    def histogram_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        sharex=True,
        sharey=False,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        histogram(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            sharex=sharex,
            sharey=sharey,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("kde", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(kde)
    def kde_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        subplots=False,
        sharex=True,
        sharey=False,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        secondary_y=False,
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        kde(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            subplots=subplots,
            sharex=sharex,
            sharey=sharey,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            secondary_y=secondary_y,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("kde_time", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(kde_time)
    def kde_time_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        subplots=False,
        sharex=True,
        sharey=False,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        secondary_y=False,
        mark_right=True,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        kde_time(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            subplots=subplots,
            sharex=sharex,
            sharey=sharey,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            secondary_y=secondary_y,
            mark_right=mark_right,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("lag_plot", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(lag_plot)
    def lag_plot_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        lag_plot_lag=1,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        lag_plot(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            lag_plot_lag=lag_plot_lag,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("lognorm_xaxis", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(lognorm_xaxis)
    def lognorm_xaxis_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        lognorm_xaxis(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("lognorm_yaxis", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(lognorm_yaxis)
    def lognorm_yaxis_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        lognorm_yaxis(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("norm_xaxis", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(norm_xaxis)
    def norm_xaxis_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        norm_xaxis(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("norm_yaxis", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(norm_yaxis)
    def norm_yaxis_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        norm_yaxis(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("probability_density", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(probability_density)
    def probability_density_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        subplots=False,
        sharex=True,
        sharey=False,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        secondary_y=False,
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        probability_density(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            subplots=subplots,
            sharex=sharex,
            sharey=sharey,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            secondary_y=secondary_y,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("scatter_matrix", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(scatter_matrix)
    def scatter_matrix_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        scatter_matrix_diagonal="kde",
        grid=False,
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        scatter_matrix(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            scatter_matrix_diagonal=scatter_matrix_diagonal,
            grid=grid,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("target", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(target)
    def target_cli(
        obs_col=None,
        sim_col=None,
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        por=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
    ):
        """docstring replaced by tsutils.copy_doc"""
        obs_col = obs_col or 1
        sim_col = sim_col or 2
        target(
            obs_col=None,
            sim_col=None,
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            por=por,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
        )

    @cltoolbox.command("taylor", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(taylor)
    def taylor_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        por=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
    ):
        """docstring replaced by tsutils.copy_doc"""
        taylor(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            por=por,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
        )

    @cltoolbox.command("time", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(time)
    def _time_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        subplots=False,
        sharex=True,
        sharey=False,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        secondary_y=None,
        mark_right=True,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        time(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            subplots=subplots,
            sharex=sharex,
            sharey=sharey,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            secondary_y=secondary_y,
            mark_right=mark_right,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("waterfall", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(waterfall)
    def waterfall_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        waterfall(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("weibull_xaxis", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(weibull_xaxis)
    def weibull_xaxis_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        weibull_xaxis(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("weibull_yaxis", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(weibull_yaxis)
    def weibull_yaxis_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        plotting_position="weibull",
        prob_plot_sort_values="descending",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        weibull_yaxis(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            plotting_position=plotting_position,
            prob_plot_sort_values=prob_plot_sort_values,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command("xy", formatter_class=RSTHelpFormatter)
    @tsutils.copy_doc(xy)
    def xy_cli(
        input_ts="-",
        columns=None,
        start_date=None,
        end_date=None,
        clean=False,
        skiprows=None,
        index_type="datetime",
        names=None,
        ofilename="plot.png",
        xtitle="",
        ytitle="",
        title="",
        figsize="10,6.0",
        legend=None,
        legend_names=None,
        colors="auto",
        linestyles="auto",
        markerstyles=" ",
        style="auto",
        xaxis="arithmetic",
        yaxis="arithmetic",
        xlim=None,
        ylim=None,
        xy_match_line="",
        grid=False,
        drawstyle="default",
        por=False,
        invert_xaxis=False,
        invert_yaxis=False,
        round_index=None,
        dropna="all",
        source_units=None,
        target_units=None,
        plot_styles="bright",
        hlines_y=None,
        hlines_xmin=None,
        hlines_xmax=None,
        hlines_colors=None,
        hlines_linestyles="-",
        vlines_x=None,
        vlines_ymin=None,
        vlines_ymax=None,
        vlines_colors=None,
        vlines_linestyles="-",
    ):
        """docstring replaced by tsutils.copy_doc"""
        xy(
            input_ts=input_ts,
            columns=columns,
            start_date=start_date,
            end_date=end_date,
            clean=clean,
            skiprows=skiprows,
            index_type=index_type,
            names=names,
            ofilename=ofilename,
            xtitle=xtitle,
            ytitle=ytitle,
            title=title,
            figsize=figsize,
            legend=legend,
            legend_names=legend_names,
            colors=colors,
            linestyles=linestyles,
            markerstyles=markerstyles,
            style=style,
            xaxis=xaxis,
            yaxis=yaxis,
            xlim=xlim,
            ylim=ylim,
            xy_match_line=xy_match_line,
            grid=grid,
            drawstyle=drawstyle,
            por=por,
            invert_xaxis=invert_xaxis,
            invert_yaxis=invert_yaxis,
            round_index=round_index,
            dropna=dropna,
            source_units=source_units,
            target_units=target_units,
            plot_styles=plot_styles,
            hlines_y=hlines_y,
            hlines_xmin=hlines_xmin,
            hlines_xmax=hlines_xmax,
            hlines_colors=hlines_colors,
            hlines_linestyles=hlines_linestyles,
            vlines_x=vlines_x,
            vlines_ymin=vlines_ymin,
            vlines_ymax=vlines_ymax,
            vlines_colors=vlines_colors,
            vlines_linestyles=vlines_linestyles,
        )

    @cltoolbox.command()
    def about():
        """Display version number and system information."""
        tsutils.about(__name__)

    cltoolbox.main()


if __name__ == "__main__":
    _main()
